@@ -30,6 +30,7 @@ __all__ = (
     "AffinityType",
     "AllocationStateType",
     "AllocationStrategyType",
+    "AllocationTypeType",
     "AllowsMultipleInstanceTypesType",
     "AnalysisStatusType",
     "ApplianceModeSupportValueType",
@@ -314,6 +315,7 @@ __all__ = (
     "ListingStateType",
     "ListingStatusType",
     "LocalGatewayRouteStateType",
+    "LocalGatewayRouteTableModeType",
     "LocalGatewayRouteTypeType",
     "LocalStorageType",
     "LocalStorageTypeType",
@@ -469,7 +471,9 @@ __all__ = (
 
 
 AcceleratorManufacturerType = Literal["amazon-web-services", "amd", "nvidia", "xilinx"]
-AcceleratorNameType = Literal["a100", "k80", "m60", "radeon-pro-v520", "t4", "v100", "vu9p"]
+AcceleratorNameType = Literal[
+    "a100", "inferentia", "k520", "k80", "m60", "radeon-pro-v520", "t4", "v100", "vu9p"
+]
 AcceleratorTypeType = Literal["fpga", "gpu", "inference"]
 AccountAttributeNameType = Literal["default-vpc", "supported-platforms"]
 ActivityStatusType = Literal["error", "fulfilled", "pending_fulfillment", "pending_termination"]
@@ -487,6 +491,7 @@ AllocationStateType = Literal[
 AllocationStrategyType = Literal[
     "capacityOptimized", "capacityOptimizedPrioritized", "diversified", "lowestPrice"
 ]
+AllocationTypeType = Literal["used"]
 AllowsMultipleInstanceTypesType = Literal["off", "on"]
 AnalysisStatusType = Literal["failed", "running", "succeeded"]
 ApplianceModeSupportValueType = Literal["disable", "enable"]
@@ -1564,6 +1569,7 @@ ListSnapshotsInRecycleBinPaginatorName = Literal["list_snapshots_in_recycle_bin"
 ListingStateType = Literal["available", "cancelled", "pending", "sold"]
 ListingStatusType = Literal["active", "cancelled", "closed", "pending"]
 LocalGatewayRouteStateType = Literal["active", "blackhole", "deleted", "deleting", "pending"]
+LocalGatewayRouteTableModeType = Literal["coip", "direct-vpc-routing"]
 LocalGatewayRouteTypeType = Literal["propagated", "static"]
 LocalStorageType = Literal["excluded", "included", "required"]
 LocalStorageTypeType = Literal["hdd", "ssd"]
@@ -1671,6 +1677,7 @@ ResourceTypeType = Literal[
     "capacity-reservation-fleet",
     "carrier-gateway",
     "client-vpn-endpoint",
+    "coip-pool",
     "customer-gateway",
     "dedicated-host",
     "dhcp-options",
@@ -1734,8 +1741,10 @@ ResourceTypeType = Literal[
     "volume",
     "vpc",
     "vpc-endpoint",
+    "vpc-endpoint-connection",
     "vpc-endpoint-connection-device-type",
     "vpc-endpoint-service",
+    "vpc-endpoint-service-permission",
     "vpc-flow-log",
     "vpc-peering-connection",
     "vpn-connection",
